/* Prise-Connectee-V2.ino
 *  
 * Programe de connection à distance avec Wemos D1 mini
 * adresse wemos locale: 192.168.0.xx donnée par mDNS
 * En local connexion avec: 192.168.0.xx:yyyy/
 *  Rem.: yyyy = port attribué au boitier de la prise sur la box
 *  
 * sur box internet: 
 *  connexion avec : Adresse-IPfixe-box:port/
 *  
 *  gaston.etienne@free.fr
 *  
 */

#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266WebServer.h>
#include <ESP8266mDNS.h>

      /****** Personnalisation prise et réseau ******/
char* ssid = "votre-SSID"; // votre reseau WiFi
char* password = "votre-password"; // votre mot de passe wifi
char* hoststring = "ESP_C35A07"; // nom donné par DHCP à modifier
long port = zzzz; // le port choisi

MDNSResponder mdns; // serveur mDNS

ESP8266WebServer server(port); // serveur HTTP

const int led = 04; // relais connecte au GPIO12 = D2
const int relay = 05; // relais connecte au GPIO05 = D1
String etatChauffage;
String getpageAcceuil;
String pageAcceuil;
String pageMarche;
String pageArret;

                /***** Page Web *****/
String getPageAcceuil(){
  pageAcceuil = "<html lang=fr-FR><head>";
  pageAcceuil += "<meta name=";
  pageAcceuil += " viewport"; pageAcceuil += " content="; pageAcceuil += "width=device-width, initial-scale=1, maximum-scale=1";
  pageAcceuil += ">";
  pageAcceuil += "</head>";
 
  pageAcceuil += "<style> body { background-color: #fffff; font-family: Arial, Helvetica, Sans-Serif; Color: #002699; }";

  //pageAcceuil += "  <style>";
  pageAcceuil += ".button {";
  pageAcceuil += "  background-color: #F0F5F5; /* Gray */";
  pageAcceuil += "  border: 2px;";
  pageAcceuil += "  color: black;";
  pageAcceuil += "  padding: 20px 20px;";
  pageAcceuil += "  border-radius: 2px;";
  pageAcceuil += "  text-align: center;";
  pageAcceuil += "  text-decoration: none;";
  pageAcceuil += "  display: none;";
  pageAcceuil += "  font-size: 16px;";
  pageAcceuil += " margin: 4px 2px;";
  pageAcceuil += "  cursor: pointer;";
  pageAcceuil += "}";
  pageAcceuil += ".button2 {background-color: #FF0000;}"; /*  = Red */ 
  pageAcceuil += ".button3 {background-color: #228B22 ;}"; //vert 
  pageAcceuil += "</style>";
 
  pageAcceuil += "<body><center><font color =#0000FF><h1>Chauffage S&#233jour</h1>";
  pageAcceuil += "<h3>by Gaston</center></h3>";
  pageAcceuil += "<br></font>";
  pageAcceuil += "<center>";
  
  if(etatChauffage =="Chauffage en marche") {
      pageAcceuil += "<font color =#228B22><h1>Chauffage en marche</h1></font>";
      }
    else {
      pageAcceuil += "<font color =#FF0000><h1><center>Chauffage arr&#234;t&#233</h1></font>"; // couleur rouge
      }
  pageAcceuil += "</center></h2><br>";
        /*  boutons marche / arrêt  pour HTML5 */
  pageAcceuil += "<p><h1><a href=\"marche\"><button3><font color =#228B22>Mise en marche</font></button></h1></a></p>";//button class="button button3"
  pageAcceuil += "<br>";
  pageAcceuil += "<p><h1><a href=\"arret\"><button2><font color =#FF0000>Arr&#234;t du chauffage</font></h1></button></a></p>";//
  pageAcceuil += "</body></html>";
  return pageAcceuil;
  }


void setup(void) {

/* Configuration des entree/sortie */
pinMode(relay, OUTPUT);
pinMode(led, OUTPUT);
digitalWrite(led, 0);
digitalWrite(relay, 0);
etatChauffage = "chauffage arr&#234;t&#233";
  Serial.begin(115200); // initialisation du port serie

connect(ssid,password); // connexion au reseau Wifi
WiFi.begin(ssid,password);
Serial.print("Server = ");
Serial.println(hoststring);
/* demarrage du serveur mDNS sur esp8266.local */
if (mdns.begin(hoststring, WiFi.localIP())) {
Serial.println("MDNS responder started");
Serial.println(WiFi.localIP());
}

/* ajout des actions du serveur */
server.on("/", handle_root);
server.on("/marche", handle_marche);
server.on("/arret", handle_arret);

server.begin(); // demarrage du serveur

Serial.println("HTTP server started");
}

void loop(void) {
server.handleClient(); // gestion du serveur

/* Si connecté au wifi alors la LED s'allume */
if (WiFi.status() == !WL_CONNECTED) digitalWrite(led, 0);
else digitalWrite(led, 1);

}

/* Routine pour se connecter à un reseau wifi */
void connect(char* _SSID, char* _PWD) {
Serial.println("");
Serial.print("Connecting ");
Serial.print(_SSID);
Serial.print(" password = ");
Serial.print( _PWD);
int h = 0;

// Wait for connection
while (WiFi.status() != WL_CONNECTED) {
delay(500);
Serial.print(".");

if (h++ > 40) { // si trop long on abandonne
Serial.println();
Serial.println("Failed to connect");
return;
}
}

Serial.println("");
Serial.print("Connected to ");
Serial.println(ssid);
Serial.print("IP address: ");
Serial.println(WiFi.localIP());
}

/* Action serveur sur /marche */
void handle_marche() {
server.send(200, "text/html", getPageMarche()); 
close(); // actionne le relais
}

void handle_arret() {
server.send(200, "text/html", getPageArret());
open(); // désactive le relais
}

void handle_root() {
/* page[] contient notre page web et renvois vers le domaine /open si on appuie sur le bouton */
server.send(200, "text/html", getPageAcceuil()); // repond avec la page web codee en HTML
}


void open() {
  digitalWrite(relay, 0); // ouvre le contact du relais
  digitalWrite(led, LOW); // eteint la led
  etatChauffage = "chauffage arr&#234;t&#233"; 
  Serial.println("Arret du chauffage");
  }

void close() {
  digitalWrite(relay,1);// ferme le contact du relais
  digitalWrite(led, HIGH); // allume la led
  etatChauffage = "Chauffage en marche";
  Serial.println("Chauffage en Marche");
  }




String getPageMarche() {
  pageMarche = "<html lang=fr-FR><head>";
  pageMarche += "<meta name=";
  pageMarche += " viewport"; pageMarche += " content="; pageMarche += "width=device-width, initial-scale=1, maximum-scale=1";
  pageMarche += ">"; 
  pageMarche += "<title>Chauffage by Gaston</title>";
  pageMarche += "\r\n";
  pageMarche += "<style> body { background-color: #fffff; font-family: Arial, Helvetica, Sans-Serif; Color: #000088; }</style>";
  pageMarche += "</head><body><center><h1>Chauffage-1 (Chambre)</h1>";
  pageMarche += "<h3>by Gaston</h3>";
  pageMarche += " <br>";
  pageMarche += "<font color =#228B22><h1>Chauffage en marche</h1></font></center>";
  pageMarche += "<br>";
  pageMarche += "<p><a href=\"arret\"><button><font color =#FF0000><h1>Arr&#234;t du chauffage</h1></button></a></p></font>";
  pageMarche += "</body></html>";
  return pageMarche;
}


String getPageArret() {
  pageArret = "<html lang=fr-FR><head>";
  pageArret += "<meta name=";
  pageArret += " viewport"; pageArret += " content="; pageArret += "width=device-width, initial-scale=1, maximum-scale=1";
  pageArret += ">";
//  pageArret += "<title>Chauffage by Gaston</title>";
//  pageArret += "<META HTTP-EQUIV="refresh" CONTENT="15">";

  pageArret += "\r\n";
  pageArret += "</head><style> body { background-color: #fffff; font-family: Arial, Helvetica, Sans-Serif; Color: #000088; }</style>";
  pageArret += "</head><body><center><h1>Chauffage-1 (Chambre)</h1>";
  pageArret += "<h3>by Gaston</h3>";
  pageArret += "<br>";
  pageArret += "<font color =#FF0000><h1>Chauffage arr&#234;t&#233</h1></font></center>"; // couleur rouge
  pageArret += "<br>";
  pageArret += "<p><a href=\"marche\"><button><font color =#228B22><h1>Mise en route du chauffage</h1></font></button></a></p></font>";
  pageArret += "</body></html>";
  return pageArret;
}


